@@ -224,6 +224,9 @@ Apt::Get::Download-Only true;
 Acquire::Languages "none";
 Dir::Etc::Trusted "/etc/apt/trusted.gpg";
 Dir::Etc::TrustedParts "/etc/apt/trusted.gpg.d";
+Acquire::http::Dl-Limit "1000";
+Acquire::https::Dl-Limit "1000";
+Acquire::Retries "5";
 END
 
 	> "$rootdir/var/lib/dpkg/status"
@@ -466,6 +469,17 @@ cleanuptmpdir() {
 export SOURCE_DATE_EPOCH=$(date --date="$(grep-dctrl -s Date -n '' "$newmirrordir/dists/$DEFAULT_DIST/Release")" +%s)
 
 if [ "$HAVE_QEMU" = "yes" ]; then
+	case "$HOSTARCH" in
+		amd64|i386)
+			# okay
+			;;
+		*)
+			echo "qemu support is only available on amd64 and i386" >&2
+			echo "because syslinux is only available on those arches" >&2
+			exit 1
+			;;
+	esac
+
 	# We must not use any --dpkgopt here because any dpkg options still
 	# leak into the chroot with chrootless mode.
 	# We do not use our own package cache here because
@@ -507,6 +521,9 @@ if [ "$HAVE_QEMU" = "yes" ]; then
 		arches=$HOSTARCH
 	fi
 	$CMD --variant=apt --architectures=$arches --include="$pkgs" \
+		--aptopt='Acquire::http::Dl-Limit "1000"' \
+		--aptopt='Acquire::https::Dl-Limit "1000"' \
+		--aptopt='Acquire::Retries "5"' \
 		$DEFAULT_DIST - "$mirror" > "$tmpdir/debian-chroot.tar"
 
 	cat << END > "$tmpdir/extlinux.conf"
@@ -540,7 +557,7 @@ END
 	cat << 'END' > "$tmpdir/worker.sh"
 #!/bin/sh
 echo 'root:root' | chpasswd
-mount -t 9p -o trans=virtio,access=any mmdebstrap /mnt
+mount -t 9p -o trans=virtio,access=any,msize=128k mmdebstrap /mnt
 # need to restart mini-httpd because we mounted different content into www-root
 systemctl restart mini-httpd
 
